Name
That doesn't look like a valid port name.
Too long port name.
Network {$ nw.name $}
You must supply a network.
Security Groups {$ sg.name $}
Admin State UP Port Security Enabled
{$ 'Show More Properties' | translate $} Allowed Address Pairs
MAC Address
That doesn't look like a valid mac address.
IP Address
That doesn't look like a valid ip address.
Fixed IPs
IP Address
That doesn't look like a valid ip address.
Subnet {$ subnet.name $}
bind:vnic_type Device ID {$ item.display $} Warning: "{$ $ctrl.searchText $}" saved with no pre-defined device owner found. QoS Policy {$ qos.name $} MAC Address
That doesn't look like a valid mac address.
Tags Value Specs
Key Value